# --- Activity Logging ---

Digunakan untuk log aplikasi nabire (apbd) 2019.


# Cara menggunakan

 - Tambahkan 
	> from global_apbd_logging import nabire_logging
 - Cara Memanggil 

	> nabire_logging.logging(request, session_username, nama_db)

# Update

 - Versi 1.0.1
  > Kirim Notifikasi ke telegram apabila gagal logging

